OC.L10N.register(
    "settings",
    {
    "Private" : "Zasebno",
    "Only visible to people matched via phone number integration through Talk on mobile" : "Vidno le uporabnikom povezanimi s programom Talk prek telefonske številke.",
    "Local" : "Krajevno",
    "Only visible to people on this instance and guests" : "Vidno le krajevnim uporabnikom in povezanim gostom",
    "Federated" : "Zvezno",
    "Only synchronize to trusted servers" : "Usklajuj le z zaupanja vrednimi strežniki",
    "Published" : "Objavljeno",
    "Synchronize to trusted servers and the global and public address book" : "Usklajuj z varnimi strežniki in splošnimi in javnimi imeniki",
    "Verify" : "Overi",
    "Verifying …" : "Poteka overjanje ...",
    "Unable to change password" : "Ni mogoče spremeniti gesla",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Slabo geslo",
    "So-so password" : "Šibko geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Groups" : "Skupine",
    "Group list is empty" : "Seznam skupin je prazen",
    "Unable to retrieve the group list" : "Ni mogoče pridobiti seznama skupin",
    "{actor} added you to group {group}" : "{actor} vas doda v skupino {group}",
    "You added {user} to group {group}" : "Uporabnika {user} dodate v skupino {group}",
    "{actor} added {user} to group {group}" : "{actor} doda uporabnika {user} v skupino {group}",
    "An administrator added you to group {group}" : "Skrbnik vas doda v skupino {group}",
    "An administrator added {user} to group {group}" : "Skrbnik doda uporabnika {user} v skupino {group}",
    "{actor} removed you from group {group}" : "{actor} vas odstrani iz skupine {group}",
    "You removed {user} from group {group}" : "Uporabnika {user} odstranite iz skupine {group}",
    "{actor} removed {user} from group {group}" : "{actor} odstrani uporabnika {user} iz skupine {group}",
    "An administrator removed you from group {group}" : "Skrbnik vas odstrani iz skupine {group}",
    "An administrator removed {user} from group {group}" : "Skrbnik odstrani uporabnika {user} iz skupine {group}",
    "Your <strong>group memberships</strong> were modified" : "Spremenjeno je vaše <strong>članstvo v skupinah</strong> ",
    "{actor} changed your password" : "{actor} spremeni moje geslo",
    "You changed your password" : "Spremenite geslo",
    "Your password was reset by an administrator" : "Skrbnik sistema ponastavi moje geslo",
    "Your password was reset" : "Geslo je bilo ponastavljeno",
    "{actor} changed your email address" : "{actor} spremeni moj elektronski naslov",
    "You changed your email address" : "Spremenite elektronski naslov",
    "Your email address was changed by an administrator" : "Skrbnik spremeni moj elektronski naslov",
    "You created app password \"{token}\"" : "Ustvarite žeton gesla programa »{token}«",
    "You deleted app password \"{token}\"" : "Izbrišeta žeton gesla programa »{token}«",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Preimenujete žeton gesla programa »{token}« to »{newToken}«",
    "You granted filesystem access to app password \"{token}\"" : "Odobrite sistemski dostop do žetona gesla programa »{token}«",
    "You revoked filesystem access from app password \"{token}\"" : "Odobrite sistemski datotečni dostop gesla programa »{token}«",
    "Security" : "Varnostna opozorila",
    "You successfully logged in using two-factor authentication (%1$s)" : "Uspešno zabeležite uporabo dvo-stopenjske overitve (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Poskus prijave z dvostopenjsko overitvijo je spodletel (%1$s)",
    "Remote wipe was started on %1$s" : "Oddaljeno varnostno brisanje je bilo začeto na %1$s.",
    "Remote wipe has finished on %1$s" : "Oddaljeno varnostno brisanje je bilo končano na %1$s.",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "Spremenjeno je bilo <strong>geslo</strong> oziroma <strong>elektronski naslov</strong>",
    "Wrong password" : "Napačno geslo",
    "Saved" : "Shranjeno",
    "No user supplied" : "Ni navedenega uporabnika",
    "Authentication error" : "Napaka overjanja",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški podatki izgubljeni.",
    "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "Program cURL uporablja zastarelo različico %1$s (%2$s). Priporočljivo je posodobiti operacijski sistem, sicer možnosti, kot je %3$s, ne bodo delovale pravilno.",
    "Invalid SMTP password." : "Neveljavno geslo SMTP",
    "Email setting test" : "Preizkus nastavitev elektronske pošte",
    "Well done, %s!" : "Odlično, %s!",
    "If you received this email, the email configuration seems to be correct." : "Če ste to sporočilo prejeli, potem nastavitev pošte deluje pravilno.",
    "Email could not be sent. Check your mail server log" : "Elektronskega sporočila ni bilo mogoče poslati. Preverite dnevnik poštnega strežnika.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
    "Invalid user" : "Neveljavni podatki uporabnika",
    "Invalid mail address" : "Neveljaven elektronski naslov",
    "Settings saved" : "Nastavitve so shranjene.",
    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
    "Unable to change email address" : "Ni mogoče spremeniti elektronskega naslova",
    "Unable to set invalid phone number" : "Ni mogoče nastaviti neveljavne telefonske številke",
    "Unable to set invalid website" : "Ni mogoče nastaviti neveljavnega spletnega mesta",
    "Some account data was invalid" : "Nekateri podatki računa niso veljavni",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Za overitev računa Twitter, objavite sporočilo (prepričajte se, da ni nobenega preloma vrstice):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Za overitev spletne strani, shranite navedeno vsebino v spletni korenski mapi v ».well-known/CloudIdVerificationCode.txt« (prepričajte se, da je celotno besedilo v eni vrstici): ",
    "%1$s changed your password on %2$s." : "%1$s spremeni vaše geslo %2$s.",
    "Your password on %s was changed." : "Vaše geslo %s je bilo spremenjeno.",
    "Your password on %s was reset by an administrator." : "Skrbnik je ponastavil vaše geslo %s.",
    "Your password on %s was reset." : "Geslo za %s je bilo ponastavljeno.",
    "Password for %1$s changed on %2$s" : "Geslo za %1$s je bilo spremenjeno %2$s",
    "Password changed for %s" : "Geslo za %s je spremenjeno",
    "If you did not request this, please contact an administrator." : "Če tega dejanja niste zahtevali, stopite nemudoma v stik s skrbnikom sistema.",
    "Your email address on %s was changed." : "Elektronski naslov za %s je spremenjen.",
    "Your email address on %s was changed by an administrator." : "Skrbnik je spremenil elektronski naslov za %s .",
    "Email address for %1$s changed on %2$s" : "Elektronski naslov računa %1$s je bil spremenjen %2$s.",
    "Email address changed for %s" : "Elektronski naslov za račun %s je spremenjen.",
    "The new email address is %s" : "Nov elektronski naslov je %s",
    "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
    "Welcome aboard" : "Dobrodošli",
    "Welcome aboard %s" : "Dobrodošli %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Omogočen je vaš dostop do oblaka %s, v katerega lahko varno dodate podatke in jih posredujete v souporabo.",
    "Your username is: %s" : "Dodeljeno uporabniško ime je: %s",
    "Set your password" : "Določitev gesla",
    "Go to %s" : "Odpri oblak %s",
    "Install Client" : "Namesti odjemalca",
    "Logged in user must be a subadmin" : "Prijavljen uporabnik mora imeti dovoljenja podpornega skrbnika",
    "Apps" : "Programi",
    "Settings" : "Nastavitve",
    "Personal" : "Osebno",
    "Administration" : "Skrbništvo",
    "Additional settings" : "Dodatne nastavitve",
    "Administration privileges" : "Skrbniška dovoljenja",
    "Groupware" : "Skupinsko delo",
    "Overview" : "Splošni pregled",
    "Basic settings" : "Osnovne nastavitve",
    "Sharing" : "Souporaba",
    "Availability" : "Razpoložljivost",
    "Personal info" : "Osebni podatki",
    "Mobile & desktop" : "Mobilni in namizni dostop",
    "Email server" : "Poštni strežnik",
    "Security & setup warnings" : "Varnost in namestitvena opozorila",
    "Background jobs" : "Opravila v ozadju",
    "Create" : "Ustvarjanje",
    "Change" : "Spreminjanje",
    "Delete" : "Brisanje",
    "Reshare" : "Nadaljnja souporaba",
    "Unlimited" : "Neomejeno",
    "Verifying" : "Preverjanje",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Na čakanju je ozadnje opravilo, ki preverja obstoj uporabniško uvoženih potrdil SSL. Ponovno preverite kasneje.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Shranjenih je nekaj potrdil SSL, ki z različico Nextcloud 21 ne bodo več v uporabi. Potrdila je mogoče uvoziti z ukazom \"occ security:certificates:import\". Zabeležene poti v podatkovnem imeniku so izpisane spodaj.",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Star način strežniškega šifriranja je še vedno omogočen. Priporočljivo je možnost izklopiti.",
    "Nextcloud settings" : "Nastavitve Nextcloud",
    "Here you can decide which group can access certain sections of the administration settings." : "Na tem mestu je mogoče določiti, katera skupina ima dostop do določenih možnosti skrbniških nastavitev.",
    "None" : "Brez",
    "Unable to modify setting" : "Ni mogoče spremeniti nastavitve",
    "Two-Factor Authentication" : "Dvo-stopenjska overitev",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Dvostopenjsko overjanje je mogoče vsiliti za vse uporabnike in določene skupine. Če za tovrstno prijavo nimajo nastavljenega ustreznega ponudnika, se v sistem ne bodo uspeli povezati.",
    "Enforce two-factor authentication" : "Vsili dvo-stopenjsko overjanje",
    "Limit to groups" : "Omeji na skupine",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Vsiljeno dvo-stopenjsko overjanje je mogoče določiti le za določene skupine.",
    "Two-factor authentication is enforced for all members of the following groups." : "Dvo-stopenjsko overjanje je vsiljeno za vse člane navedenih skupin.",
    "Enforced groups" : "Obvezno za skupine",
    "Two-factor authentication is not enforced for members of the following groups." : "Dvo-stopenjsko overjanje ni obvezno za člane navedenih skupin.",
    "Excluded groups" : "Izločene skupine",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Ko so skupine izbrane/izključene, je v uporabi protokol za ugotavljanje, ali ima uporabnik vsiljeno uporabo dvostopenjskega overjanja 2FA. Če ni izbrane skupine, je 2FA omogočeno za vse, razen za člane izključenih skupin. Če skupine so izbrane, je 2FA omogočeno za vse člane teh skupin, če pa je uporabnik v izbrani in tudi v izključeni skupini, ima izbrana skupina prednost in 2FA se izvaja.",
    "Save changes" : "Shrani spremembe",
    "All" : "Vsi",
    "Limit app usage to groups" : "Omeji uporabo programa na skupine",
    "No results" : "Ni zadetkov",
    "Update to {version}" : "Posodobi na različico {version}",
    "Remove" : "Odstrani",
    "Disable" : "Onemogoči",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcloud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Program nima določene omejitve različice okolja Nextcoud. V prihodnosti se bo manjkajoči podatek pokazal kot napaka.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerazrešenih odvisnosti:",
    "View in store" : "Pokaži v trgovini",
    "Visit website" : "Odpri spletno stran",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "User documentation" : "Uporabniška dokumentacija",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "This app is supported via your current Nextcloud subscription." : "Program je podprt prek trenutne naročnine Nextcloud",
    "Supported" : "Podprto",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Uradne programe razvijajo posamezniki, ki sodelujejo s skupnostjo. Paketi vključujejo osrednje zmožnosti programa, uporaba pa je namenjena tudi končnim uporabnikom.",
    "Featured" : "Izbrano",
    "Update to {update}" : "Posodobi na različico {update}",
    "Results from other categories" : "Rezultati iskanja med drugimi kategorijami",
    "No apps found for your version" : "Za navedeni iskalni niz ni programov",
    "Disable all" : "Onemogoči vse",
    "Enable all" : "Omogoči vse",
    "_%n app has an update available_::_%n apps have an update available_" : ["Na voljo je posodobitev za %n program.","Na voljo sta posodobitvi za %n programa.","Na voljo so posodobitve za %n programe.","Na voljo so posodobitve za %n programov."],
    "Marked for remote wipe" : "Označeno za oddaljeno varnostno brisanje",
    "Device settings" : "Nastavitve naprave",
    "Allow filesystem access" : "Dovoli dostop do datotečnega sistema",
    "Rename" : "Preimenuj",
    "Revoke" : "Prekliči",
    "Wipe device" : "Varnostno izbriši napravo",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Microsoft Edge",
    "Firefox" : "Mozilla Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome za Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "{productName} iOS app" : "{productName} za iOS",
    "{productName} Android app" : "{productName} za Android",
    "{productName} Talk for iOS" : "{productName} Talk za iOS",
    "{productName} Talk for Android" : "{productName} Talk za Android",
    "Sync client - {os}" : "Usklajevalnik – {os}",
    "This session" : "Ta seja",
    "Device" : "Naprava",
    "Last activity" : "Zadnja dejavnost",
    "Devices & sessions" : "Naprave in seje",
    "Web, desktop and mobile clients currently logged in to your account." : "Spletne, namizne in mobilne naprave, ki so trenutno povezane z računom.",
    "Do you really want to wipe your data from this device?" : "Ali res želite varnostno izbrisati podatke s te naprave?",
    "Confirm wipe" : "Potrdi varnostno brisanje",
    "Error while creating device token" : " Napaka med ustvarjanjem žetona naprave",
    "Error while updating device token scope" : "Napaka med posodabljanjem obsega žetona naprave",
    "Error while updating device token name" : "Napaka med posodabljanjem imena žetona naprave",
    "Error while deleting the token" : " Napaka med brisanjem žetona",
    "Error while wiping the device with the token" : "Napaka med varnostnim brisanjem naprave z žetonom",
    "App name" : "Ime programa",
    "Create new app password" : "Ustvari novo geslo programa",
    "Use the credentials below to configure your app or device." : "Uporabi shranjena poverila za nastavitev programa ali naprave.",
    "For security reasons this password will only be shown once." : "Iz varnostnih razlogov bo to geslo pokazano zgolj enkrat.",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Done" : "Končano",
    "Show QR code for mobile apps" : "Pokaži kodo QR za mobilne programe",
    "Copied!" : "Kopirano!",
    "Copy" : "Kopiraj",
    "Could not copy app password. Please copy it manually." : "Gesla programa ni mogoče kopirati. Storite to ročno.",
    "Last job ran {relativeTime}." : "osvežitev je bila nazadnje izvedena {relativeTime}.",
    "AJAX" : "AJAX",
    "Execute one task with each page loaded. Use case: Single user instance." : "izvede eno nalogo z vsako naloženo stranjo. Možnost uporabe: okolje enega uporabnika.",
    "Webcron" : "Webcron",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "Osveževanje z datoteko cron.php omogoča storitev webcron  in sicer vsakih 5 minut po protokolu HTTP. Možnost je uporabna za manše število uporabnikov (1–5 udeležencev z nezahtevnim načinom rabe okolja).",
    "Cron (Recommended)" : "Cron (priporočeno)",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Za zagon te možnosti je zahtevana razširitev PHP POSIX. Več podrobnosti je zapisanih v {linkstart}dokumentaciji PHP{linkend}.",
    "Use system cron service to call the cron.php file every 5 minutes. Recommended for all instances." : "Uporabljena je sistemska storitev »cron«, ki vzpostavi povezavo z datoteko cron.php vsakih 5 minut. Priporočeno za vse vrste rabe okolja.",
    "Profile" : "Profil",
    "Enable" : "Omogoči",
    "Server-side encryption" : "Šifriranje na strežniku",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Šifriranje na strežniku omogoča šifriranje datotek, poslanih na strežnik. Opravilo ima tudi omejitvene učinke, kot je vpliv na hitrost delovanja, Možnost je na voljo po potrebi.",
    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ko je šifriranje enkrat omogočeno, bodo v času manjše aktivnosti šifrirane vse datoteke, poslane na strežnik. Šifriranje bo mogoče izklopiti šele kasneje, če bo uporabljen šifrirni modul podpiral tovrstno funkcionalnost in bodo doseženi vsi ostali pogoji (na primer, ustrezno nastavljeni obnovitveni ključi).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifriranje samo po sebi še ne zagotavlja varnosti sistema. Več podorobnosti o delovanju programa in primeri uporabe so zabeleženi v dokumentaciji.",
    "Be aware that encryption always increases the file size." : " Upoštevajte, da šifriranje poveča velikost datoteke.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Priporočljivo je redno ustvarjati varnostne kopije podatkov, v primeru šifriranja pa varnostno kopirati tudi šifrirne ključe.",
    "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali res želite omogočiti šifriranje?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Modul za šifriranje ni naložen. Pred nadaljevanjem je treba modul določiti v seznamu programov.",
    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
    "Rename group" : "Preimenuj skupino",
    "Remove group" : "Odstrani skupino",
    "You are about to remove the group {group}. The users will NOT be deleted." : "Odstranili boste skupino {group}. Uporabniki ne bodo odstranjeni.",
    "Please confirm the group removal " : "Potrditi je treba odstranjevanje skupine",
    "Current password" : "Trenutno geslo",
    "New password" : "Novo geslo",
    "Change password" : "Spremeni geslo",
    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
    "Picture provided by original account" : "Slika iz izvornega računa",
    "Cancel" : "Prekliči",
    "Your biography" : "Biografija",
    "Details" : "Podrobnosti",
    "You are a member of the following groups:" : "Omogočeno je članstvo v skupinah:",
    "Your full name" : "Polno ime",
    "Email options" : "Možnosti elektronske pošte",
    "Primary email for password reset and notifications" : "Osnovni elektronski naslov za obnavljanje gesla in obvestila",
    "Remove primary email" : "Odstrani osnovni elektronski naslov",
    "Delete email" : "Izbriši elektronski naslov",
    "Unset as primary email" : "Odstrani oznako osnovnega elektronskega naslova",
    "This address is not confirmed" : "Ta naslov ni potrjen",
    "Set as primary email" : "Nastavi kot osnovni elektronski naslov",
    "Your email address" : "Osebni elektronski naslov",
    "Additional email address {index}" : "Dodatni elektronski naslov {index}",
    "Unable to delete primary email address" : "Ni mogoče izbrisati osnovnega elektronskega naslova",
    "Unable to update primary email address" : "Ni mogoče posodobiti osnovnega elektronskega naslova",
    "Unable to add additional email address" : "Ni mogoče dodati dodatnega elektronskega naslova",
    "Unable to update additional email address" : "Ni mogoče posodobiti dodatnega elektronskega naslova",
    "Unable to delete additional email address" : "Ni mogoče izbrisati dodatnega elektronskega naslova",
    "No email address set" : "Poštni naslov ni nastavljen",
    "Additional emails" : "Dodatni elektronski naslovi",
    "Your headline" : "Vaš naslov",
    "Language" : "Jezik",
    "Help translate" : "Sodelujte pri prevajanju",
    "Unable to update language" : "Ni mogoče posodobiti jezika",
    "No language set" : "Jezik ni nastavljen",
    "Locale" : "Jezikovne nastavitve",
    "Your organisation" : "Ustanova",
    "Your phone number" : "Osebna telefonska številka",
    "Edit your Profile visibility" : "Prilagodi vidnost profila",
    "Enable Profile" : "Omogoči profil",
    "Unable to update profile enabled state" : "Ni mogoče posodobiti omogočenega stanja profila",
    "{displayId}" : "{displayId}",
    "Unable to update visibility of {displayId}" : "Ni mogoče posodobiti vidnosti {displayId}",
    "Your role" : "Vloga",
    "Add additional email" : "Dodaj dodaten elektronski naslov",
    "Add" : "Dodaj",
    "You do not have permissions to see the details of this user" : "Ni ustreznih dovoljenj za pregled podatkov uporabnika",
    "Add new password" : "Vpis gesla",
    "Add new email address" : "Vpis elektronskega naslova",
    "Add user to group" : "Dodaj uporabnika v skupino",
    "Set user as admin for" : "Nastavi uporabnika kot skrbnika za",
    "Select user quota" : "Količinska omejitev prostora",
    "Delete user" : "Izbriši uporabnika",
    "Wipe all devices" : "Varnostno izbriši vse naprave",
    "Disable user" : "Onemogoči uporabnika",
    "Enable user" : "Omogoči uporabnika",
    "Resend welcome email" : "Ponovno pošlji potrditveno sporočilo",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Možnost omogoča varnostno brisanje podatkov Nextcloud z vseh naprav, povezanih z uporabniškim računom {userid}. Možnost deluje le, če so naprave povezane v spletno omrežje. Brisanje z oddaljenih naprav je uporabno v primeru izgubljene naprave, ali na primer prekinitve sodelovanja v neki skupini.",
    "Remote wipe of devices" : "Oddaljeno varnostno brisanje naprav",
    "Wipe {userid}'s devices" : "Varnostno izbriši naprave uporabniškega računa {userid}",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Izbriši račun »{userid}« vključno z osebnimi podatki, datotekami, programi ...",
    "Account deletion" : "Brisanje računa",
    "Delete {userid}'s account" : "Izbriši račun {userid}",
    "Welcome mail sent!" : "Potrditveno sporočilo je poslano!",
    "Edit User" : "Uredi podatke uporabnika",
    "Toggle user actions menu" : "Preklopi meni uporabniških dejanj",
    "{size} used" : "Uporabljeno {size}·",
    "New user" : "Nov uporabnik",
    "Will be autogenerated" : "Samodejno ustvarjeno",
    "Display name" : "Prikazno ime",
    "Email" : "Elektronski naslov",
    "Default language" : "Privzeti jezik",
    "Add a new user" : "Dodaj uporabnika",
    "Group admin for" : "Skrbnik skupine za",
    "Quota" : "Količinska omejitev",
    "User backend" : "Uporabniški ozadnji program",
    "Storage location" : "Mesto shrambe",
    "Last login" : "Zadnja prijava",
    "No users in here" : "Ni še vključenih uporabnikov",
    "Default quota" : "Privzeta omejitev",
    "Common languages" : "Splošni jeziki",
    "Other languages" : "Drugi jeziki",
    "Password change is disabled because the master key is disabled" : "Spreminjanje gesla je onemogočeno, ker je onemogočen tudi glavni šifrirni ključ",
    "Passwordless authentication requires a secure connection." : "Brezgeselna overitev zahteva varno povezavo.",
    "Add WebAuthn device" : "Dodaj napravo WebAuthn",
    "Please authorize your WebAuthn device." : "Overite napravo WebAuthn",
    "Name your device" : "Naziv naprave",
    "Adding your device …" : "Poteka dodajanje naprave ..",
    "Server error while trying to add WebAuthn device" : "Prišlo je do strežniške napake med dodajanjem naprave WebAuthn",
    "Server error while trying to complete WebAuthn device registration" : "Prišlo je do strežniške napake med zaključevanjem vpisovanja naprave WebAuthn",
    "Unnamed device" : "Neimenovana naprava",
    "Passwordless Authentication" : "Brezgeselna overitev",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Nastavitev račun za brezgeselno overitev dostopa po standardu FIDO2.",
    "No devices configured." : "Ni nastavljenih naprav.",
    "The following devices are configured for your account:" : "Z vašim računom so povezane navedene naprave:",
    "Your browser does not support WebAuthn." : "Brskalnik ne podpira overitve WebAuthn.",
    "Your apps" : "Vsi programi",
    "Active apps" : "Zagnani programi",
    "Disabled apps" : "Onemogočeni programi",
    "Updates" : "Posodobitve",
    "App bundles" : "Paketi programov",
    "Featured apps" : "Predlagani programi",
    "{license}-licensed" : "dovoljenje {license}",
    "Changelog" : "Dnevnik sprememb",
    "by {author}\n{license}" : "Razvoj: {author}\nDovoljenje: {license}",
    "Enter group name" : "Vpis imena skupine",
    "Add group" : "Dodaj skupino",
    "Active users" : "Dejavni uporabniki",
    "Admins" : "Skrbniki",
    "Disabled users" : "Onemogočeni uporabniki",
    "Default quota:" : "Privzeta količinska omejitev :",
    "Select default quota" : "Izbor količinske omejitve",
    "Show Languages" : "Pokaži jezike",
    "Show last login" : "Pokaži zadnjo prijavo",
    "Show user backend" : "Pokaži ozadnji program",
    "Show storage path" : "Pokaži pot mesta shrambe",
    "Send email to new user" : "Pošlji sporočilo novemu uporabniku",
    "Not saved" : "Ni shranjeno",
    "Sending…" : "Poteka pošiljanje ...",
    "Email sent" : "Elektronsko sporočilo je poslano",
    "Location" : "Trenutno mesto",
    "Profile picture" : "Slika profila",
    "About" : "O programu",
    "Full name" : "Polno ime",
    "Additional email" : "Dodatni elektronski naslov",
    "Headline" : "Naslov",
    "Organisation" : "Ustanova",
    "Phone number" : "Telefonska številka",
    "Role" : "Vloga",
    "Twitter" : "Račun Twitter",
    "Website" : "Spletna stran",
    "Profile visibility" : "Vidnost profila",
    "Show to everyone" : "Pokaži vsem",
    "Hide" : "Skrij",
    "Download and enable" : "Prejmi in omogoči",
    "Enable untested app" : "Omogoči nepreizkušen program",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Ta program ni označen kot skladen z nameščeno različico oblaka Nextcloud. Če nameravate nadaljevati, boste program lahko namestili, vendar ta morda ne bo deloval po pričakovanjih, ali pa bo vplival na stabilnost sistema.",
    "Never" : "Nikoli",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Program je omogočen, vendar zahteva posodobitev. Po nekaj sekundah boste preusmerjeni na stran za posodobitev.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Napaka: tega programa ni mogoče namestiti, ker povzroča nestabilnost strežnika.",
    "Administrator documentation" : "Skrbniška dokumentacija",
    "Documentation" : "Dokumentacija",
    "Forum" : "Forum",
    "Login" : "Prijava",
    "Plain" : "Besedilno",
    "NT LAN Manager" : "Upravljalnik NT LAN",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Open documentation" : "Odprta dokumentacija",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Strežnik mora biti za pošiljanje sporočil ustrezno nastavljen. Velja tudi za pošiljanje povezav za ponastavitev gesla..",
    "Send mode" : "Način pošiljanja",
    "Encryption" : "Šifriranje",
    "Sendmail mode" : "Način sendmail",
    "From address" : "Naslov pošiljatelja",
    "Authentication method" : "Način overitve",
    "Authentication required" : "Zahtevana je overitev",
    "Server address" : "Naslov strežnika",
    "Port" : "Vrata",
    "Credentials" : "Poverila",
    "SMTP Username" : "Uporabniško ime SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Save" : "Shrani",
    "Send email" : "Pošlji elektronsko sporočilo",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Zaradi varnosti in optimizacije delovanja je pomembno, da je sistem pravilno nastavljen. Za preverjanj se nekateri preizkusi izvajajo samodejno. Več podrobnosti je zabeleženih v dokumentaciji. ",
    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
    "There are some errors regarding your setup." : "Med preverjanjem je bilo zaznanih je nekaj napak namestitve.",
    "There are some warnings regarding your setup." : "Med preverjanjem je bilo zbranih nekaj opozoril.",
    "Checking for system and security issues." : "Preverjanje sistemskih in varnostnih nastavitev.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Preverite <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">namestitveno dokumentacijo ↗</a> in morebitne napake oziroma opozorila v <a href=\"%2$s\">sistemskem dnevniku</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Preverite varnost storitev Nextcloud s <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">preverjalnikom ↗</a>.",
    "Version" : "Različica",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Skrbnik lahko prilagodi možnosti souporabe. Več podrobnosti je zapisanih v dokumentaciji.",
    "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
    "Set default expiration date for shares" : "Nastavi privzeti datuma poteka za mesta souporabe",
    "Expire after" : "Poteče po",
    "day(s)" : "dneh",
    "Enforce expiration date" : "Vsili datum preteka",
    "Set default expiration date for shares to other servers" : "Nastavi privzeti datuma poteka za mesta souporabe na drugih strežnikih",
    "Allow users to share via link and emails" : "Uporabnikom dovoli omogočanje souporabe s povezavami in elektronskimi sporočili",
    "Allow public uploads" : "Dovoli javno pošiljanje datotek v oblak",
    "Always ask for a password" : "Vedno zahtevaj geslo",
    "Enforce password protection" : "Vsili zaščito z geslom",
    "Set default expiration date" : "Nastavi privzeti datum poteka",
    "Allow resharing" : "Dovoli nadaljnje omogočanje souporabe",
    "Allow sharing with groups" : "Dovoli souporabo s skupinami",
    "Restrict users to only share with users in their groups" : "Uporabnikom dovoli omogočanje souporabe le znotraj njihove skupine",
    "Exclude groups from sharing" : "Izbranim skupinam onemogoči omogočanje souporabe",
    "These groups will still be able to receive shares, but not to initiate them." : "Te skupine lahko sprejemajo mape v souporabo, nimajo pa dovoljenja za omogočanje souporabe.",
    "Allow username autocompletion in share dialog" : "Dovoli samodejno dopolnjevanje uporabniških imen v oknu omogočanja souporabe",
    "Allow username autocompletion to users within the same groups" : "Dovoli samodejno dopolnjevanje uporabniških imen znotraj iste skupine",
    "Allow username autocompletion to users based on phone number integration" : "Dovoli samodejno dopolnjevanje uporabniških imen po telefonskih številkah",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Če je omogočeno samodejno dopolnjevanje »v isti skupini«, ali pa »po telefonskem imeniku«, se zadetek pokaže, če je uporabnik v katerikoli od teh zbirk.",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Pokaži izjavo o omejitvi odgovornosti pri uporabi javnih povezav za pošiljanje (če je onemogočen prikaz seznama datotek).",
    "This text will be shown on the public link upload page when the file list is hidden." : "Besedilo izjave o omejitvi odgovornosti, ki bo izpisano v oknu za pošiljanje, ko je možnost prikaza seznama datotek onemogočena.",
    "Default share permissions" : "Privzeta dovoljenja souporabe",
    "Reasons to use Nextcloud in your organization" : "Razlogi za uporabo oblaka Nextcloud v vaši organizaciji",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Okolje razvija {communityopen}skupnost Nextcloud{linkclose}, {githubopen}izvorna koda{linkclose} pa je objavljena pod pogoji dovoljenja {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Spremljajte naš Facebook",
    "Follow us on Twitter" : "Sledite nam na Twitter!",
    "Follow us on Mastodon" : "Sledite nam na Mastodon",
    "Check out our blog" : "Preverite naš blog",
    "Subscribe to our newsletter" : "Naročite se na novice",
    "Use a second factor besides your password to increase security for your account." : "Ob geslu je priporočljivo uporabiti tudi drugo-stopenjsko overitev za večjo varnost računa.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Če uporabljate za povezavo z oblakom Nextcloud programe tretjih oseb, najprej ustvarite in nastavite gesla za vsak program, preden omogočite dvostopenjsko overitev.",
    "Migration in progress. Please wait until the migration is finished" : "V teku je preselitev. Počakajte, da se zaključi.",
    "Migration started …" : "Preselitev je začeta ...",
    "An error occurred while changing your language. Please reload the page and try again." : "Med spreminjanjem jezika je prišlo do napake. Poskusite ponovno naložiti stran in poskusite znova.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Med spreminjanjem jezikovnih nastavitev je prišlo do napake. Poskusite ponovno naložiti stran in poskusite znova.",
    "Select a profile picture" : "Izbor slike profila",
    "Week starts on {fdow}" : "Začetek tedna je {fdow}",
    "Couldn't remove app." : "Programa ni mogoče odstraniti.",
    "Couldn't update app." : "Programa ni mogoče posodobiti.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "Ozadnji program ne podpira spreminjanja gesla, je pa uspešno posodobljeno uporabniški šifrirni ključ.",
    "Could not determine if TLS version of cURL is outdated or not because an error happened during the HTTPS request against https://nextcloud.com. Please check the nextcloud log file for more details." : "Ni mogoče določiti, ali je različica TLS cURL zastarela ali ne, ker je do napake prišlo med izvajanjem zahteve HTTPS prek https://nextcloud.com. Za več podrobnosti si oglejte datoteko dnevnika nextcloud.",
    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "Obnovitev tega žetona lahko prepreči varnostno brisanje naprave, če se to še ni začelo.",
    "Set as primary mail" : "Nastavi kot osnovni elektronski naslov",
    "Change privacy level of email" : "Spremeni pravila zasebnosti za elektronski naslov",
    "All languages" : "Vsi jeziki",
    "Everyone" : "Vsi",
    "An error occured during the request. Unable to proceed." : "Med izvajanjem zahteve je prišlo do napake, zato ni mogoče nadaljevati.",
    "Test email settings" : "Preizkus nastavitev elektronske pošte",
    "Please read carefully before activating server-side encryption: " : "Pred omogočanjem strežniškega šifriranja pozorno preberite opombe:",
    "Enable encryption" : "Omogoči šifriranje",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud ≤ 8.0) na novega. Omogočite možnost »Privzeti šifrirni modul« in zaženite ukaz »occ encryption:migrate«.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Preseliti je treba šifrirne ključe iz starega sistema (ownCloud <= 8.0) na novega.",
    "Start migration" : "Začni selitev",
    "Last job execution ran %s. Something seems wrong." : "Zadnji poskus izvedbe je bil izveden %s. Kaže, da je nekaj narobe.",
    "Some jobs haven’t been executed since %s. Please consider increasing the execution frequency." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je povečati pogostost izvajanja.",
    "Some jobs didn’t execute since %s. Please consider switching to system cron." : "Nekatera opravila niso bila izvedena od %s. Priporočljivo je preklopiti na sistemska opravila cron.",
    "Last job ran %s." : "Zadnje opravilo je bilo izvedeno %s.",
    "Background job didn’t run yet!" : "Ni bilo izvedenega še nobenega opravila v ozadju.",
    "Pick background job setting" : "Izbor nastavitve ozadnjih opravil",
    "Recommended" : "Priporočljivo",
    "The cron.php needs to be executed by the system user \"%s\"." : "Datoteka cron.php mora biti izvedena za uporabnika »%s«.",
    "days" : "dneh.",
    "Allow username autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Dovoli samodejno dokončanje uporabniškega imena pri vpisu polnega imena ali elektronskega naslova (prezrta je zahteva telefonskega imenika in iste skupine).",
    "Change privacy level of profile picture" : "Spremeni pravila zasebnosti profilne slike",
    "Upload new" : "Pošlji novo",
    "Select from Files" : "Izbor iz datotek",
    "Remove image" : "Odstrani sliko",
    "Choose as profile picture" : "Izberi kot sliko profila",
    "You are using <strong>%s</strong>" : "Uporabljate <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "V uporabi je <strong>%1$s</strong> od <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Change privacy level of full name" : "Spremeni pravila zasebnosti za polno ime",
    "No display name set" : "Prikazno ime ni nastavljeno",
    "Change privacy level of phone number" : "Spremeni pravila zasebnosti za telefonsko številko",
    "Address" : "Naslov",
    "Change privacy level of address" : "Spremeni pravila zasebnosti za naslov",
    "Your postal address" : "Osebni poštni naslov",
    "Change privacy level of website" : "Spremeni pravila zasebnosti za spletno stran",
    "It can take up to 24 hours before the account is displayed as verified." : "Dokončno overjanje računa lahko traja tudi do 24 ur.",
    "Link https://…" : "Povezava https:// …",
    "Change privacy level of Twitter profile" : "Spremeni pravila zasebnosti za profil Twitter",
    "Twitter handle @…" : "Twitter @ …",
    "Admin privileges" : "Dovoljenja skrbnika",
    "Unable to update biography" : "Ni mogoče posodobiti biografije",
    "Unable to update full name" : "Ni mogoče posodobiti polnega imena",
    "No full name set" : "Ni nastavljenega polnega imena",
    "Unable to update headline" : "Ni mogoče posodobiti naslova",
    "Unable to update organisation" : "Ni mogoče posodobiti imena ustanove",
    "Unable to update role" : "Ni mogoče posodobiti vloge",
    "Avatar" : "Podoba"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
